==> arnie-0.2.22.tgz: package/lib/operators/when.test.js <==
'use strict';

var _taggedTemplateLiteral2 = require('babel-runtime/helpers/taggedTemplateLiteral');

var _taggedTemplateLiteral3 = _interopRequireDefault(_taggedTemplateLiteral2);

var _templateObject = (0, _taggedTemplateLiteral3.default)(['path.falsy'], ['path.falsy']),
    _templateObject2 = (0, _taggedTemplateLiteral3.default)(['path.foo'], ['path.foo']),
    _templateObject3 = (0, _taggedTemplateLiteral3.default)(['path.bar'], ['path.bar']);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var t = require('tap');
var A = require('../');
var arnie = A();
var when = require('./when');
var input = require('../tags/input');

t.test('Operator: when', function (t) {
  t.plan(5);

  var task = [when(function (_ref) {
    var input = _ref.input;
    return input.path.truthy;
  }), {
    true: [function () {
      t.pass('should trigger path "true" when truthy');
    }],
    false: [function () {
      t.fail('should NOT trigger this path');
    }]
  }, when(input(_templateObject)), {
    true: [function () {
      t.fail('should NOT trigger this path');
    }],
    false: [function () {
      t.pass('should trigger path "false" when falsy');
    }]
  }, when(function (_ref2) {
    var input = _ref2.input;
    return input.path.number > 5;
  }), {
    true: [function () {
      t.pass('should evaluate function to true or false path');
    }],
    false: [function () {
      t.fail('should NOT trigger this path');
    }]
  }, when(input(_templateObject2)), {
    bar: [function () {
      t.pass('should trigger path where path name matches value');
    }],
    otherwise: [function () {
      t.fail('should NOT trigger this path');
    }]
  }, when(input(_templateObject3)), {
    foo: [function () {
      t.fail('should NOT trigger this path');
    }],
    otherwise: [function () {
      t.pass('should trigger path "otherwise" if path with value is not set');
    }]
  }];

  var payload = {
    path: {
      truthy: 1,
      falsy: null,
      foo: 'bar',
      number: 10,
      bar: 'something-else'
    }
  };
  arnie(task, payload).catch(console.error);
});

==> arnie-0.3.5.tgz: package/lib/operators/when.test.js <==
'use strict';

var _taggedTemplateLiteral2 = require('babel-runtime/helpers/taggedTemplateLiteral');

var _taggedTemplateLiteral3 = _interopRequireDefault(_taggedTemplateLiteral2);

var _templateObject = (0, _taggedTemplateLiteral3.default)(['path.falsy'], ['path.falsy']),
    _templateObject2 = (0, _taggedTemplateLiteral3.default)(['path.foo'], ['path.foo']),
    _templateObject3 = (0, _taggedTemplateLiteral3.default)(['path.bar'], ['path.bar']);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var t = require('tap');
var A = require('../');
var arnie = A();
var when = require('./when');
var props = require('../tags/props');

t.test('Operator: when', function (t) {
  t.plan(5);

  var task = [when(function (_ref) {
    var props = _ref.props;
    return props.path.truthy;
  }), {
    true: [function () {
      t.pass('should trigger path "true" when truthy');
    }],
    false: [function () {
      t.fail('should NOT trigger this path');
    }]
  }, when(props(_templateObject)), {
    true: [function () {
      t.fail('should NOT trigger this path');
    }],
    false: [function () {
      t.pass('should trigger path "false" when falsy');
    }]
  }, when(function (_ref2) {
    var props = _ref2.props;
    return props.path.number > 5;
  }), {
    true: [function () {
      t.pass('should evaluate function to true or false path');
    }],
    false: [function () {
      t.fail('should NOT trigger this path');
    }]
  }, when(props(_templateObject2)), {
    bar: [function () {
      t.pass('should trigger path where path name matches value');
    }],
    otherwise: [function () {
      t.fail('should NOT trigger this path');
    }]
  }, when(props(_templateObject3)), {
    foo: [function () {
      t.fail('should NOT trigger this path');
    }],
    otherwise: [function () {
      t.pass('should trigger path "otherwise" if path with value is not set');
    }]
  }];

  var payload = {
    path: {
      truthy: 1,
      falsy: null,
      foo: 'bar',
      number: 10,
      bar: 'something-else'
    }
  };
  arnie(task, payload).catch(console.error);
});
